from setuptools import setup, find_packages

setup(
    name="FC16004UNO",
    version="0.1.0",
    description="Librería para resolver sistemas de ecuaciones lineales y no lineales",
    author="RiAlF",
    author_email="tu_correo@ejemplo.com",
    packages=find_packages(),
    install_requires=[],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)